{ config, pkgs, ... }:

{
  imports =
    [
      ./common-headless.nix
    ];

  boot.supportedFilesystems = ["zfs"];
  boot.loader.grub = {
    enable = true;
    version = 2;
    zfsSupport = true;
    mirroredBoots = [
      { devices = [ "/dev/sda" ]; path = "/boota"; }
      { devices = [ "/dev/sdb" ]; path = "/bootb"; }
      { devices = [ "/dev/sdc" ]; path = "/bootc"; }
      { devices = [ "/dev/sdd" ]; path = "/bootd"; }
      { devices = [ "/dev/sde" ]; path = "/boote"; }
      { devices = [ "/dev/sdf" ]; path = "/bootf"; }
    ];
  };

  networking = {
    hostName = "aplysia";
    hostId = "34a820f1";
  };

  services.openssh.enable = true;

  users.extraUsers.gebner = {
    isNormalUser = true;
    extraGroups = ["wheel" "transmission"];
  };

  boot.kernelPackages = pkgs.lib.mkOverride 10 pkgs.linuxPackages;

  system.stateVersion = "17.03";

  fileSystems."/mnt/aplysia" = pkgs.lib.mkOverride 10 {
    device = "aplysia/export";
    fsType = "zfs";
  };

  services.samba = {
    enable = true;
    extraConfig = ''
      passdb backend = tdbsam
      unix password sync = no
    '';
    shares = {
      export = {
        "guest ok" = "no";
        path = "/mnt/aplysia";
      };
    };
  };

  networking.firewall = {
    # samba
    allowedTCPPorts = [ 445 139 ];
    allowedUDPPorts = [ 137 138 ];
  };

}
